<?php 
// get website title
if(!function_exists("nvr_document_title")){
	function nvr_document_title(){
		/*
		 * Print the <title> tag based on what is being viewed.
		 */
		global $page, $paged;
	
		wp_title( '|', true, 'right' );
		if( !defined('WPSEO_URL') ){
			// Add the blog name.
			bloginfo( 'name' );
		
			// Add the blog description for the home/front page.
			$site_description = get_bloginfo( 'description', 'display' );
			if ( $site_description && ( is_home() || is_front_page() ) )
				echo " | $site_description";
		
			// Add a page number if necessary:
			if ( $paged >= 2 || $page >= 2 )
				echo ' | ' . sprintf( __( 'Page %s', THE_LANG ), max( $paged, $page ) );
		}
	}// end nvr_document_title()
}

// head action hook
if(!function_exists("nvr_head")){
	function nvr_head(){
		do_action("nvr_head");
	}
	add_action('wp_head', 'nvr_head', 20);
}

if(!function_exists("nvr_metaviewport")){
	function nvr_metaviewport(){
		$dis_viewport = nvr_get_option(THE_SHORTNAME . '_disable_viewport');
		if(!$dis_viewport){
			echo '<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1" />';
		}
	}
	add_action('nvr_head', 'nvr_metaviewport', 5);
}

if(!function_exists("nvr_print_headmiscellaneous")){
	function nvr_print_headmiscellaneous(){
	
		echo "<!--[if lt IE 9]>\n";
		echo "<script src='".THE_JSURI."html5shiv.js type='text/javascript'></script>\n";
		echo "<![endif]-->\n";

        $favicon = nvr_get_option( THE_SHORTNAME . '_favicon');
        if($favicon =="" ){
            $favicon = get_template_directory_uri() . '/images/favicon.ico';
        }
		echo '<link rel="shortcut icon" href="' . $favicon . '" />';
        
	}
	add_action('nvr_head', 'nvr_print_headmiscellaneous', 6);
}

// print the logo html
if(!function_exists("nvr_logo")){
	function nvr_logo(){ 
		
		$shortname = THE_SHORTNAME;
		$logotype = nvr_get_option( $shortname . '_logo_type');
		$logoimage = nvr_get_option( $shortname . '_logo_image'); 
		$sitename =  nvr_get_option( $shortname . '_site_name');
		$tagline = nvr_get_option( $shortname . '_tagline');
		
		if($sitename=="") $sitename = get_bloginfo('name');
		if($tagline=="") $tagline = get_bloginfo('description'); 
		if($logoimage == "") $logoimage = get_stylesheet_directory_uri() . "/images/logo.png"; 
?>
		<?php if($logotype == 'textlogo'){ ?>
			
			<h1><a href="<?php echo home_url( '/'); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', THE_LANG ) ); ?>"><?php echo $sitename; ?></a></h1><span class="desc"><?php echo $tagline; ?></span>
        
        <?php } else { ?>
        	
            <div class="logoimg">
            <a href="<?php echo home_url( '/' ) ; ?>" title="<?php echo $sitename; ?>" >
                <img src="<?php echo $logoimage ; ?>" alt="<?php echo $sitename; ?>" />
            </a>
            </div>
            
		<?php } ?>
        
<?php 
	}
}

if(!function_exists("nvr_searchform")){
	function nvr_searchform($id="", $class=""){
		if(function_exists('is_woocommerce')){
			$outputposttype = '<input type="hidden" name="post_type" value="product" />';
			$searchtext = __('Search product...', THE_LANG );
		}else{
			$outputposttype = '';
			$searchtext = __('Search...', THE_LANG );
		}
		$output = '<div class="'.$class.'">';
			$output .= '<form method="get" id="'.$id.'" class="btntoppanel" action="'. esc_url( home_url( '/' ) ) .'">';
				$output .= '<input type="submit" class="submit" name="submit" value="" />';
				$output .= '<div class="searcharea">';
					$output .= '<input type="text" name="s" class="txtsearch" placeholder="'. $searchtext .'" value="" />';
					$output .= $outputposttype;
				$output .= '</div>';
			$output .= '</form>';
		$output .= '</div>';
		
		return $output;
	}
}

if (!function_exists('nvr_socialicon')){
	function nvr_socialicon(){
		
		$shortname = THE_SHORTNAME;
		$optSocialIcons = nvr_fontsocialicon();
		
		$outputli = "";
		for($i=1;$i<=count($optSocialIcons);$i++){
			$socialoption = nvr_get_option( $shortname . '_socialicon_'.$i, "" );
			
			if(is_array($socialoption) && $socialoption['select']!='0'){
				$socialicon = $socialoption['select'] ;
				$sociallink = $socialoption['text'];
				$outputli .= '<li><a href="'.$sociallink.'" class="fa '.$socialicon.'"></a></li>'."\n";
			}
		}
		$output = "";
		if($outputli!=""){
			$output .= '<ul class="sn">';
			$output .= $outputli;
			$output .= '</ul>';
		}
		return $output;
	}
}//end if(!function_exists('nvr_get_socialicon'))

if(!function_exists('nvr_breadcrumb')){
	function nvr_breadcrumb(){
		if(function_exists('woocommerce_breadcrumb')){
			woocommerce_breadcrumb();
		}elseif(function_exists('yoast_breadcrumb')){
			yoast_breadcrumb('<nav class="nvr-breadcrumb">','</nav><div class="clearfix"></div>');
		}
	}
}

if(!function_exists("nvr_minicart")){
	function nvr_minicart($id="",$class=""){
		
		global $woocommerce;
		$cart_subtotal = $woocommerce->cart->get_cart_subtotal();
		$link = $woocommerce->cart->get_cart_url();
		$cart_items = $woocommerce->cart->get_cart_item_quantities();
		
		$totalqty = 0;
		if(is_array($cart_items)){
			foreach($cart_items as $cart_item){
				$totalqty += (is_numeric($cart_item))? $cart_item : 0;
			}
		}
		
		ob_start();
		the_widget('WC_Widget_Cart', '', array('widget_id'=>'cart-dropdown',
			'before_widget' => '',
			'after_widget' => '',
			'before_title' => '<span class="hidden">',
			'after_title' => '</span>'
		));
		$widget = ob_get_clean();
	
		$output = '<div id="'.$id.'" class="'.$class.'">';
			$output .= '<a class="topcartbutton btnpanel" href="'.$link.'">'.__('My Cart', THE_LANG).'<br /><span class="cart_subtotal">'.$cart_subtotal.'</span><span class="cart_subqty"><i class="fa fa-shopping-cart"></i><i class="cart_totalqty">'.$totalqty.'</i></span></a>';
			$output .= '<span class="arrowpanel"></span>';
			$output .= '<div class="cartlistwrapper">';
				$output .= $widget;
			$output .= '</div>';
		$output .= '</div>';
		
		return $output;
	}
}

if(!function_exists('nvr_output_headertext')){
	function nvr_output_headertext(){
		$shortname = THE_SHORTNAME;
		/*=====HEADERTEXT======*/
		$headertext = stripslashes(nvr_get_option( $shortname . '_headertext',''));
		if($headertext){
			echo '<div class="toptext"><span>'. do_shortcode($headertext) .'</span></div>';
		}
	}
	add_action('nvr_output_toparea','nvr_output_headertext',5);
}

if(!function_exists('nvr_output_headertext2')){
	function nvr_output_headertext2(){
		$shortname = THE_SHORTNAME;
		/*=====HEADERTEXT======*/
		$headertext = stripslashes(nvr_get_option( $shortname . '_headertext2',''));
		if($headertext){
			echo '<div class="toptext text2"><span>'. do_shortcode($headertext) .'</span></div>';
		}
	}
	add_action('nvr_output_toparea','nvr_output_headertext2',8);
}

if(!function_exists('nvr_output_headertext3')){
	function nvr_output_headertext3(){
		$shortname = THE_SHORTNAME;
		/*=====HEADERTEXT======*/
		$headertext = stripslashes(nvr_get_option( $shortname . '_headertext3',''));
		if($headertext){
			echo '<div class="rightlogotext text3"><span>'. do_shortcode($headertext) .'</span></div>';
		}
	}
}

if(!function_exists('nvr_output_socialicon')){
	function nvr_output_socialicon(){
		/*=====SOCIALICON======*/
		$socialiconoutput = nvr_socialicon();
		if($socialiconoutput!=''){				
			// get the social network icon
			echo '<div class="topicon">'. $socialiconoutput .'</div>';
		}
	}
	add_action('nvr_output_toparea','nvr_output_socialicon',10);
	
}

if(!function_exists('nvr_output_wpmlselector')){
	function nvr_output_wpmlselector(){
		do_action('icl_language_selector');
	}
	add_action('nvr_output_toparea','nvr_output_wpmlselector',20);
}

if(!function_exists('nvr_primary_menu')){
	function nvr_primary_menu($class=''){
		echo '<section class="navigation '.$class.'">';
			echo '<nav>';
			wp_nav_menu( array(
			  'container'       => 'ul', 
			  'menu_class'      => 'topnav sf-menu', 
			  'depth'           => 0,
			  'sort_column'    => 'menu_order',
			  'fallback_cb'     => 'nav_page_fallback',
			  'theme_location' => 'mainmenu' 
			)); 
			echo '</nav><!-- nav -->';	
			echo '<div class="clearfix"></div>';
		echo '</section>';
	}
}

if(!function_exists('nvr_secondary_menu')){
	function nvr_secondary_menu(){
		echo '<nav id="secondarymenu">';
		
		wp_nav_menu( array(
		  'container'       => 'ul', 
		  'menu_class'      => 'sf-menu',
		  'menu_id'         => 'secondarynav', 
		  'depth'           => 1,
		  'sort_column'    => 'menu_order',
		  'theme_location' => 'secondarymenu' 
		  )); 

		echo '</nav><!-- nav -->';	
	}
	add_action('nvr_output_toparea','nvr_secondary_menu',15);
}

if(!function_exists('nvr_output_searchbox')){
	function nvr_output_searchbox(){
		$shortname = THE_SHORTNAME;
		$disable_topsearch = nvr_get_option($shortname . '_disable_topsearch');
		if($disable_topsearch!='1'){
			echo nvr_searchform("","searchbox columns"); 
		}
	}
}

if(!function_exists('nvr_output_minicart')){
	function nvr_output_minicart(){
		$shortname = THE_SHORTNAME;
		
		$disable_minicart = nvr_get_option($shortname . '_disable_minicart');
		if($disable_minicart!=true && function_exists('is_woocommerce')){
			echo nvr_minicart("topminicart","commercepanel");
		}
	}
}