<?php

add_action( 'after_setup_theme', 'nvr_setup' );

if ( ! function_exists( 'nvr_setup' ) ):

function nvr_setup() {

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// This theme uses post thumbnails
	if ( function_exists( 'add_theme_support' ) ) { // Added in 2.9
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'woocommerce' );
		add_image_size( 'blog-post-image', 700, 394, true ); // Blog Image
		add_image_size( 'post-thumb', 100, 100, true ); // Recent Post Widget Image
		add_image_size( 'testimonial-thumb', 100, 100, true ); // Testimonial Image
		add_image_size( 'portfolio-image', 700, 394, true ); // Portfolio Image Original
		add_image_size( 'portfolio-image-square', 700, 700, true ); // Portfolio Image Square
		add_image_size( 'portfolio-image-portrait', 700, 9999, true ); // Portfolio Image Portrait
		add_image_size( 'portfolio-image-landscape', 700, 394, true ); // Portfolio Image Landscape
		add_image_size( 'brand-image', 220, 104, true ); // Portfolio Image Col 4
		add_image_size( 'product-big-image', 700, 700, true ); // Product Big Image
	}

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'gallery', 'video', 'audio' ) );
	
	// Removing the sidebar in woocommerce
	remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar', 10 );
	/* 270x330 16px 11px 16px 11px*/
	/*remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_title', 5 );*/

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'mainmenu' => __( 'Main Menu', THE_LANG )
	) );
	register_nav_menus( array(
		'secondarymenu' => __( 'Secondary Menu', THE_LANG )
	) );
	
	//function for woocommerce customization
	nvr_woocommerce();
}
endif;

function exceptation(){
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
}

/***** START - All functions for woocommerce customization *****/
function nvr_woocommerce(){
	/* Main Page Woocommerce Changes */
	add_filter('woocommerce_show_page_title', 'nvr_woocommerce_show_page_title');
	add_filter('woocommerce_breadcrumb_defaults', 'nvr_woocommerce_breadcrumb_defaults');
	add_filter('loop_shop_columns', 'nvr_loop_shop_columns');
	add_filter('yith_wcwl_button_label','nvr_wclc_wishlist_text');
	add_filter('yith-wcwl-browse-wishlist-label','nvr_wclc_browse_wishlist_text');
	remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb' , 20);
	add_action( 'woocommerce_before_shop_loop', 'nvr_woocommerce_shop_filter', 40 );
	
	/* Loop Woocommerce Changes */
	add_action( 'woocommerce_before_shop_loop', 'nvr_woocommerce_loop_ulprod_wrapper_start', 40 );
	add_action( 'woocommerce_after_shop_loop', 'nvr_woocommerce_loadmore_ajax',9);
	add_action( 'woocommerce_after_shop_loop', 'nvr_woocommerce_loop_ulprod_wrapper_end', 6 );
	
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_show_product_loop_sale_flash', 10 );
	remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
	add_action( 'woocommerce_before_shop_loop_item', 'woocommerce_show_product_loop_sale_flash', 5 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_list_wrapper_start', 6 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_img_wrapper_start', 7 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_btn_wrapper_start', 8 );
	if(function_exists('yith_wishlist_constructor')){
		add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_wishlist', 9 );
	}
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_quickview', 9 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_btn_wrapper_end', 10 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_template_loop_product_thumbnail', 12 );
	add_action( 'woocommerce_before_shop_loop_item', 'nvr_woocommerce_loop_img_wrapper_end', 14 );
	
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
	remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
	add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_price', 15 );
	add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_rating', 20 );
	add_action( 'woocommerce_after_shop_loop_item_title', 'nvr_woocommerce_product_categories', 15 );
	
	add_action( 'woocommerce_after_shop_loop_item', 'nvr_woocommerce_product_detail_button', 9 );
	add_action( 'woocommerce_after_shop_loop_item', 'nvr_woocommerce_loop_list_wrapper_end', 11 );
	
	/* Single Product Page changes*/
	remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
	add_action( 'woocommerce_after_single_product_summary', 'nvr_woocommerce_upsell_display', 15 );
	add_filter( 'woocommerce_output_related_products_args', 'nvr_woocommerce_output_related_products_args' );
	
}

function nvr_woocommerce_show_page_title(){
	return false;
}

function nvr_woocommerce_breadcrumb_defaults(){
	return array(
		'delimiter'   => ' &nbsp;&#47;&nbsp; ',
		'wrap_before' => '<nav class="nvr-breadcrumb" itemprop="breadcrumb">',
		'wrap_after'  => '</nav>',
		'before'      => '',
		'after'       => '',
		'home'        => _x( 'Home', 'breadcrumb', 'woocommerce' ),
	);
}

function nvr_loop_shop_columns(){
	$initial = THE_INITIAL;
	$shortname = THE_SHORTNAME;
	
	$pid = nvr_get_postid();
	$custom = nvr_get_customdata($pid);
	
	$pagelayout = nvr_get_sidebar_position($pid);
	
	if($pagelayout!='one-col'){
		$return = 3;
	}else{
		$return = 4;
	}
	return $return;
}

function nvr_woocommerce_use_masonry(){
	$shortname = THE_SHORTNAME;
	
	$shopmasonry = nvr_get_option( $shortname . '_shop_masonry' ,'0');
	if(isset($_GET['masonry']) && $_GET['masonry']=='true'){
		$shopmasonry = '1';
	}
	$shopmasonry = ($shopmasonry=='1')? true : false;
	return $shopmasonry;
}

function nvr_wclc_wishlist_text($return=''){
	if($return!='Add to Wishlist' || $return!=''){
		$return = __('Wishlist', THE_LANG);
	}
	return $return;
}

function nvr_wclc_browse_wishlist_text($return=''){
	
	$return = '<i class="fa fa-check"></i> ADDED' ;
	return $return;
}

function nvr_woocommerce_shop_filter(){
	$shortname = THE_SHORTNAME;
	
	$shopmasonry = nvr_woocommerce_use_masonry();
	
	$shopfilter = nvr_get_option( $shortname . '_shop_filter');
	if(isset($_GET['prodfilter']) && $_GET['prodfilter']=='true'){
		$shopfilter = '1';
	}
 	$shopfilter = ( $shopfilter=="1" && $shopmasonry)? true : false;
	
	if($shopfilter){
		$productcats = get_terms( 'product_cat', array( 'hide_empty' => true ) );
		
		$liprodcats = '<li class="selected"><a href="#filter" data-option-value="*">'.__('All', THE_LANG).'</a></li>';
		foreach($productcats as $productcat){
			$liprodcats .= '<li class=""><a href="#filter" data-option-value=".product-cat-'.$productcat->slug.'">'.$productcat->name.'</a></li>';
		}
		echo '<div class="isotope-filter-container">';
			echo '<ul class="isotope-filter">';
				echo $liprodcats;
			echo '</ul>';
			echo '<div class="clearfix"></div>';
		echo '</div>';
	}
	
}

function nvr_woocommerce_loop_ulprod_wrapper_start(){
	$shortname = THE_SHORTNAME;
	
	$shopmasonry = nvr_woocommerce_use_masonry();
	if($shopmasonry){
		$wrapclass = 'nvr-productmasonry';
	}else{
		$wrapclass = '';
	}
	echo '<div class="'.$wrapclass.' prodlist-col">';
}

function nvr_woocommerce_loop_ulprod_wrapper_end(){
	echo '</div>';
}

function nvr_woocommerce_loop_list_wrapper_start(){
	echo '<span class="nvr-featuredbadge"></span>';
	echo '<div class="nvr-productitem">';
}

function nvr_woocommerce_loop_list_wrapper_end(){
	echo '</div>';
}

function nvr_woocommerce_loop_img_wrapper_start(){
	echo '<div class="nvr-productloop-img">';
}

function nvr_woocommerce_loop_img_wrapper_end(){
	echo '</div>';
}

function nvr_woocommerce_loop_btn_wrapper_start(){
	echo '<div class="btn_container">';
}

function nvr_woocommerce_loop_wishlist(){
	global $product;
	
	update_option('yith_wcwl_add_to_wishlist_icon', 'fa fa-heart');
	echo '<div class="btnloop">'.do_shortcode('[yith_wcwl_add_to_wishlist]').'</div>';
}

function nvr_woocommerce_loop_quickview(){
	global $product;
	$nonce = wp_create_nonce("nvr_quickviewproduct_nonce");
    $ajaxlink = admin_url('admin-ajax.php?ajax=true&action=nvr_quickviewproduct&post_id='.$product->id.'&nonce='.$nonce);
    echo '<a href="'. $ajaxlink .'" data-rel="quickview" class="btnloop nvr_quickview"><em class="icon-quickview fa fa-search-plus"></em> '. apply_filters( 'out_of_stock_add_to_cart_text', __( 'Quick View', THE_LANG ) ) .'</a>';
}

function nvr_woocommerce_loop_btn_wrapper_end(){
	echo '</div>';
}

function nvr_woocommerce_template_loop_product_thumbnail(){
	global $product;

	$custom = nvr_get_customdata($product->id);
	$isfeatured = (isset($custom['_featured'][0]) && $custom['_featured'][0]=='yes')? true : false;
	$shopmasonry = nvr_woocommerce_use_masonry();
	
	if($isfeatured && $shopmasonry){
		echo woocommerce_get_product_thumbnail('product-big-image');
	}else{
		echo woocommerce_get_product_thumbnail();
	}
}

function nvr_woocommerce_product_detail_button(){
	global $product;
	if($product->product_type=='simple'){
		echo '<a href="'. esc_url( get_permalink($product->id) ) .'" rel="nofollow" class="button btndetail">'.__('Details', THE_LANG).'</a>';
	}
}

function nvr_woocommerce_loadmore_ajax(){
	$shortname = THE_SHORTNAME;
	
	$shopmasonry = nvr_woocommerce_use_masonry();
	
	$infscrolls = nvr_get_option( $shortname . '_shop_infscrolls');
	if(isset($_GET['infinitescroll']) && $_GET['infinitescroll']=='true'){
		$infscrolls = '1';
	}
 	$infscrolls = ( $infscrolls=="1" && $shopmasonry)? true : false;
	if( $infscrolls ){
		echo '<div id="loadmore-paging">';
			echo '<div class="loadmorebutton">';
				next_posts_link( __( 'Load More', THE_LANG ) );
			echo '</div>';
		echo '</div>';
		remove_action('woocommerce_after_shop_loop','woocommerce_pagination',10);
	}
}

function nvr_woocommerce_product_categories(){
	global $product;
	echo '<div class="nvr-productcat">';
		the_terms( $product->id, 'product_cat', '', ', ' );
	echo '</div>';
}

function nvr_woocommerce_output_related_products_args() {
  global $product;
	
	$args = array(
		'posts_per_page' => 3,
		'columns' => 3,
		'orderby' => 'rand'
	);
	return $args;
}

function nvr_woocommerce_upsell_display(){
	woocommerce_upsell_display( 4, 4);
}
/***** END - All functions for woocommerce customization *****/

/***** START - All functions, hooks, and filters for visual composer customization *****/
if(function_exists('vc_map')){
	add_action('init', 'nvr_vc_update');
	function nvr_vc_update(){
		$vcrow_params = array(
			'params' => array(
				array(
					'type' => 'colorpicker',
					'heading' => __( 'Font Color', THE_LANG ),
					'param_name' => 'font_color',
					'description' => __( 'Select font color', THE_LANG ),
					'edit_field_class' => 'vc_col-md-6 vc_column'
				),
				array(
					'type' => 'colorpicker',
					'heading' => __( 'Custom Background Color', THE_LANG ),
					'param_name' => 'bg_color',
					'description' => __( 'Select backgound color for your row', THE_LANG ),
					'edit_field_class' => 'col-md-6'
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Padding', THE_LANG ),
					'param_name' => 'padding',
					'description' => __( 'You can use px, em, %, etc. or enter just number and it will use pixels.', THE_LANG ),
					'edit_field_class' => 'col-md-6'
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Top margin', THE_LANG ),
					'param_name' => 'margin_top',
					'description' => __( 'You can use px, em, %, etc. or enter just number and it will use pixels.', THE_LANG ),
					'edit_field_class' => 'col-md-6'
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Bottom margin', THE_LANG ),
					'param_name' => 'margin_bottom',
					'description' => __( 'You can use px, em, %, etc. or enter just number and it will use pixels.', THE_LANG ),
					'edit_field_class' => 'col-md-6'
				),
				array(
					'type' => 'attach_image',
					'heading' => __( 'Background Image', THE_LANG ),
					'param_name' => 'bg_image',
					'description' => __( 'Select background image for your row', THE_LANG )
				),
				array(
					'type' => 'dropdown',
					'heading' => __( 'Background Repeat', THE_LANG ),
					'param_name' => 'bg_image_repeat',
					'value' => array(
									  __( 'Default', THE_LANG ) => '',
									  __( 'Cover', THE_LANG ) => 'cover',
								  __('Contain', THE_LANG) => 'contain',
								  __('No Repeat', THE_LANG) => 'no-repeat'
								),
					'description' => __( 'Select how a background image will be repeated', THE_LANG ),
					'dependency' => array( 'element' => 'bg_image', 'not_empty' => true)
				),
				array(
					'type' => 'textfield',
					'heading' => __( 'Extra class name', THE_LANG ),
					'param_name' => 'el_class',
					'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', THE_LANG ),
				)
			)
		);
		vc_map_update('vc_row', $vcrow_params);
		
		vc_add_param("vc_row", array(
			"type" => "dropdown",
			"class" => "",
			"show_settings_on_create"=>true,
			"heading" => __("Row Type", THE_LANG),
			"param_name" => "row_type",
			"value" => array(
				"Row" => "row",
				"Section" => "section"
			)
			
		));
		vc_add_param("vc_row", array(
			"type" => "textfield",
			"class" => "",
			"heading" => __("Anchor ID", THE_LANG),
			"param_name" => "anchor",
			"value" => ""
		));
		vc_add_param("vc_row", array(
			"type" => "dropdown",
			"class" => "",
			"heading" => __("Use Video background?", THE_LANG),
			"param_name" => "video",
			"description" => "",
			"value" => array(
				"No" => "no",
				"Yes" => "show_video"
				
			),
			"dependency" => Array('element' => "row_type", 'value' => array('section'))
		));
		vc_add_param("vc_row", array(
			"type" => "checkbox",
			"class" => "",
			"heading" => __("Video overlay", THE_LANG),
			"value" => array(__("Use transparent overlay over video?", THE_LANG) => "show_video_overlay" ),
			"param_name" => "video_overlay",
			"description" => "",
			"dependency" => Array('element' => "video", 'value' => array('show_video'))
		));
		vc_add_param("vc_row", array(
			"type" => "textfield",
			"class" => "",
			"heading" => __("Video background (webm) file url", THE_LANG),
			"value" => "",
			"param_name" => "video_webm",
			"description" => "",
			"dependency" => Array('element' => "video", 'value' => array('show_video'))
		));
		vc_add_param("vc_row", array(
			"type" => "textfield",
			"class" => "",
			"heading" => __("Video background (mp4) file url", THE_LANG),
			"value" => "",
			"param_name" => "video_mp4",
			"description" => "",
			"dependency" => Array('element' => "video", 'value' => array('show_video'))
		));
		vc_add_param("vc_row", array(
			"type" => "textfield",
			"class" => "",
			"heading" => __("Video background (ogv) file url", THE_LANG),
			"value" => "",
			"param_name" => "video_ogv",
			"description" => "",
			"dependency" => Array('element' => "video", 'value' => array('show_video'))
		));
		vc_add_param("vc_row", array(
			"type" => "attach_image",
			"class" => "",
			"heading" => __("Video preview image", THE_LANG),
			"value" => "",
			"param_name" => "video_image",
			"description" => "",
			"dependency" => Array('element' => "video", 'value' => array('show_video'))
		));
	}
}

function novaro_row_buildStyle( $bg_image = '', $bg_color = '', $bg_image_repeat = '', $font_color = '', $padding = '', $margin_bottom = '', $margin_top = '' ) {
	$has_image = false;
	$style = '';
	if ( (int)$bg_image > 0 && ( $image_url = wp_get_attachment_url( $bg_image, 'large' ) ) !== false ) {
		$has_image = true;
		$style .= "background-image: url(" . $image_url . ");";
	}
	if ( ! empty( $bg_color ) ) {
		$style .= vc_get_css_color( 'background-color', $bg_color );
	}
	if ( ! empty( $bg_image_repeat ) && $has_image ) {
		if ( $bg_image_repeat === 'cover' ) {
			$style .= "background-repeat:no-repeat;background-size: cover;";
		} elseif ( $bg_image_repeat === 'contain' ) {
			$style .= "background-repeat:no-repeat;background-size: contain;";
		} elseif ( $bg_image_repeat === 'no-repeat' ) {
			$style .= 'background-repeat: no-repeat;';
		}
	}
	if ( ! empty( $font_color ) ) {
		$style .= vc_get_css_color( 'color', $font_color ); // 'color: '.$font_color.';';
	}
	if ( $padding != '' ) {
		$style .= 'padding: ' . ( preg_match( '/(px|em|\%|pt|cm)$/', $padding ) ? $padding : $padding . 'px' ) . ';';
	}
	if ( $margin_bottom != '' ) {
		$style .= 'margin-bottom: ' . ( preg_match( '/(px|em|\%|pt|cm)$/', $margin_bottom ) ? $margin_bottom : $margin_bottom . 'px' ) . ';';
	}
	if( $margin_top != '' ) {
		$style .= 'margin-top: '.(preg_match('/(px|em|\%|pt|cm)$/', $margin_top) ? $margin_top : $margin_top.'px').';';
	}
	return empty( $style ) ? $style : ' style="' . $style . '"';
}
/***** END - All functions, hooks, and filters for visual composer customization *****/