<?php

/*********For Localization**************/
load_theme_textdomain( THE_LANG, get_template_directory().'/languages' );

$locale = get_locale();
$locale_file = get_template_directory()."/languages/$locale.php";
if ( is_readable($locale_file) )
    require_once($locale_file);
/*********End For Localization**************/

if( !function_exists('nvr_register_font') ){
	function nvr_register_font ( $sectionName ) {		
		$got_font=of_get_option($sectionName);
		
		if ($got_font!="0") {
			$font_pieces = explode(":", $got_font);
			
			$font_name = $font_pieces[0];
			$font_name = str_replace (" ","+", $font_pieces[0] );
			
			if( isset($font_pieces[1]) ){
				$font_variants = $font_pieces[1];
				$font_variants = ":" . str_replace ("|",",", $font_pieces[1] );
			}else{
				$font_variants = "";
			}
			
			wp_register_style( $sectionName, '//fonts.googleapis.com/css?family='.$font_name . $font_variants );
			return true;
		}else{
			return false;
		}
		
	}
}

// The excerpt based on character
if(!function_exists("nvr_string_limit_char")){
	function nvr_string_limit_char($excerpt, $substr=0, $strmore = "..."){
		$string = strip_tags(str_replace('...', '...', $excerpt));
		if ($substr>0) {
			$string = substr($string, 0, $substr);
		}
		if(strlen($excerpt)>=$substr){
			$string .= $strmore;
		}
		return $string;
	}
}
// The excerpt based on words
if(!function_exists("nvr_string_limit_words")){
	function nvr_string_limit_words($string, $word_limit){
	  $words = explode(' ', $string, ($word_limit + 1));
	  if(count($words) > $word_limit)
	  array_pop($words);
	  
	  return implode(' ', $words);
	}
}

if ( ! isset( $content_width ) )
	$content_width = 610;


/* Remove inline styles printed when the gallery shortcode is used.*/
function nvr_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'nvr_remove_gallery_css' );

if(!function_exists('nvr_readsocialicon')){
	function nvr_readsocialicon(){
		$opt_social_icons_path = get_template_directory() . '/images/social/';
		$optSocialIcons = array();
		
		if ( is_dir($opt_social_icons_path) ) {
			if ($opt_social_icons_dir = opendir($opt_social_icons_path) ) { 
				$optSocialIcons[] = "None";
				while ( ($opt_social_icons_file = readdir($opt_social_icons_dir)) !== false ) {
					if(stristr($opt_social_icons_file, ".png") !== false && stristr($opt_social_icons_file, "@2x.") === false) {
						$optSocialIcons[$opt_social_icons_file] = $opt_social_icons_file;
					}
				}    
			}
		}
		return $optSocialIcons;
	}
}

if(!function_exists('nvr_fontsocialicon')){
	function nvr_fontsocialicon(){
		$optSocialIcons = array(
			'0' => 'None',
			'fa-dribbble' => 'Dribbble',
			'fa-facebook' => 'Facebook',
			'fa-flickr' => 'Flickr',
			'fa-foursquare' => 'Foursquare',
			'fa-github' => 'Github',
			'fa-google-plus' => 'Google Plus',
			'fa-instagram' => 'Instagram',
			'fa-linkedin' => 'LinkedIn',
			'fa-pinterest' => 'Pinterest',
			'fa-skype' => 'Skype',
			'fa-tumblr' => 'Tumblr',
			'fa-twitter' => 'Twitter',
			'fa-vimeo-square' => 'Vimeo',
			'fa-youtube' => 'Youtube'
		);
		
		
		return $optSocialIcons;
	}
}

/*Prints HTML with meta information for the current post (category, tags and permalink).*/
if ( ! function_exists( 'nvr_posted_in' ) ) :
function nvr_posted_in() {
	// Retrieves tag list of current post, separated by commas.
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'Categories: %1$s <br/> Tags: %2$s', THE_LANG );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'Categories: %1$s', THE_LANG );
	} else {
		$posted_in = __( '', THE_LANG );
	}
	// Prints the string, replacing the placeholders.
	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;

/*Clearing the automatic paragraphs and breaks on shortcodes that WordPress is adding automatically when filtering content.*/
function nvr_content_formatter($content) { 
	$content = do_shortcode(shortcode_unautop($content)); 
	$content = preg_replace('#^<\/p>|^<br \/>|<p>$#', '', $content);
	$content = str_replace('<br />', '', $content);
	$content = str_replace('<p><div', '<div', $content);
	return $content;
}

/* for top menu */
function nav_page_fallback() {
if(is_front_page()){$class="current_page_item";}else{$class="";}
print '<ul class="topnav sf-menu"><li class="'.$class.'"><a href=" '.home_url( '/') .' " title=" '.__('Click for Home',THE_LANG).' ">'.__('Home',THE_LANG).'</a></li>';
    wp_list_pages( 'title_li=&sort_column=menu_order' );
print '</ul>';
}

function nav_2nd_fallback() {
	print '';
}


/* Filter Custom Post Type Categories */
function nvr_add_taxonomy_filters() {
	global $typenow;
 
	// an array of all the taxonomies you want to display. Use the taxonomy name or slug
	if($typenow=="slider-view"){
	$taxonomies = array('slidercat');
	}elseif($typenow=="pdetail"){
	$taxonomies = array('portfoliocat');
	}elseif($typenow=="testimonial-view"){
	$taxonomies = array('testimonialcat');
	}else{
	$taxonomies = array();
	}
 
	// must set this to the post type you want the filter(s) displayed on
	if($typenow == $typenow &&  $typenow != "page" && $typenow != "post"){
 	if(count($taxonomies) > 0) {
		foreach ($taxonomies as $tax_slug) {
			$tax_obj = get_taxonomy($tax_slug);
			$tax_name = $tax_obj->labels->name;
			$terms = get_terms($tax_slug);
			if(count($terms) > 0) {
				echo "<select name='$tax_slug' id='$tax_slug' class='postform'>";
				echo "<option value=''>".__('Show All Categories',THE_LANG)."</option>";
				foreach ($terms as $term) { 
					echo '<option value='. $term->slug, $_GET[$tax_slug] == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>'; 
				}
				echo "</select>";
			}
		}
		}
	}
}
add_action( 'restrict_manage_posts', 'nvr_add_taxonomy_filters' );

/* for tagcloud widget  */
add_filter( 'widget_tag_cloud_args', 'nvr_tag_cloud_args' );
function nvr_tag_cloud_args( $args ) {
	$args['number'] = 20; // show less tags
	$args['largest'] = 12; // make largest and smallest the same - i don't like the varying font-size look
	$args['smallest'] = 12;
	$args['unit'] = 'px';
	$args['format'] = 'array';
	return $args;
}

add_filter('wp_tag_cloud','wp_tag_cloud_filter', 10, 2);
function wp_tag_cloud_filter($return, $args)
{
  $strreturn = "";
  if(is_array($return)){
	  foreach($return as $ret){
		$strreturn .="<span class='tag'>".$ret."</span>";
	  }
  }
  echo '<div id="tag-cloud">'.$strreturn.'</div>';
}

/* for shortcode widget  */
add_filter('widget_text', 'do_shortcode');

function change_posttype() {
  if( is_tax('portfoliocat') && !is_admin() ) {
    set_query_var( 'post_type', array( 'post', 'portofolio' ) );
  }
  return;
}
add_action( 'parse_query', 'change_posttype' );

if( !function_exists('nvr_check_pagepost')){
	function nvr_check_pagepost(){
		global $post;
		
		if( is_404() || is_archive() || is_attachment() || is_search() ){
			$custom = false;
		}else{
			$custom = true;
		}
		
		return $custom;
	}
}

if( !function_exists('nvr_get_postid')){
	function nvr_get_postid(){
		global $post;
		
		if( is_home() ){
			$pid = get_option('page_for_posts');
		}elseif( function_exists( 'is_woocommerce' ) && is_shop() ){
			$pid = woocommerce_get_page_id( 'shop' );
		}elseif( function_exists( 'is_woocommerce' ) && is_product_category() ){
			$pid = woocommerce_get_page_id( 'shop' );
		}elseif( function_exists( 'is_woocommerce' ) && is_product_tag() ){
			$pid = woocommerce_get_page_id( 'shop' );
		}elseif(!nvr_check_pagepost()){
			$pid = 0;
		}else{
			$pid = get_the_ID();
		}
		
		return $pid;
	}
}

if( !function_exists('nvr_get_customdata')){
	function nvr_get_customdata($pid=""){
		global $post;
		
		if($pid!=""){
			$custom = get_post_custom($pid);
			return $custom;
		}
		
		if($pid==""){
			$pid = nvr_get_postid();
		}

		if( nvr_check_pagepost() ){
			$custom = get_post_custom($pid);
		}else{
			$custom = array();
		}
		
		return $custom;
	}
}

if( !function_exists('nvr_get_bodycontainer')){
	function nvr_get_bodycontainer(){
		$txtContainerWidth = intval( nvr_get_option( THE_SHORTNAME . '_container_width') );
		$optionDefault = nvr_get_default_values();
		if($txtContainerWidth<940){
			$txtContainerWidth = $optionDefault[THE_SHORTNAME . '_container_width'];
		}elseif($txtContainerWidth >1200){
			$txtContainerWidth = 1200;
		}
		return $txtContainerWidth;
	}
}

if( !function_exists('nvr_update_option')){
	function nvr_update_coption($key,$value){
		$optionname = THE_SHORTNAME;
		
		$arrval = array(
			$key => $value
		);
		if(get_option( $optionname )){
			$options = get_option($optionname);
			$options[$key] = $value;
			update_option($optionname, $options);
		}else{
			add_option($optionname, $arrval);
		}
	}
}

if( !function_exists('nvr_use_option')){
	function nvr_get_coption($key){
		$optionname = THE_SHORTNAME;
		
		$options = get_option( $optionname );
		if ( isset( $options[$key] ) ) {
			return $options[$key];
		}
		return false;
	}
}